@@ -1,3 +1,4 @@
+import dataclasses
 from dataclasses import dataclass
 from typing import Callable, ClassVar, Dict, List, Optional, Union
 
@@ -18,6 +19,8 @@ class Options:
     :param info: Meta-information for the endpoint specification.
     :param default_security_scheme: Security scheme to apply to endpoints, unless overridden on a per-endpoint basis.
     :param extra_types: Extra types in addition to those found in operation signatures. Use a dictionary to group related types.
+    :param success_responses: Associates operation response types with HTTP status codes.
+    :param error_responses: Associates error response types with HTTP status codes.
     :param property_description_fun: Custom transformation function to apply to class property documentation strings.
     :param captions: User-defined captions for sections such as "Operations" or "Types", and (if applicable) groups of extra types.
     """
@@ -26,6 +29,12 @@ class Options:
     info: Info
     default_security_scheme: Optional[SecurityScheme] = None
     extra_types: Union[List[type], Dict[str, List[type]], None] = None
+    success_responses: Dict[type, Union[int, str]] = dataclasses.field(
+        default_factory=dict
+    )
+    error_responses: Dict[type, Union[int, str]] = dataclasses.field(
+        default_factory=dict
+    )
     property_description_fun: Optional[Callable[[type, str, str], str]] = None
     captions: Optional[Dict[str, str]] = None
 
@@ -34,8 +43,6 @@ class Options:
         "Types": "Types",
         "Events": "Events",
         "AdditionalTypes": "Additional types",
-        "BadRequest": "The server cannot process the request due a client error (e.g. malformed request syntax).",
-        "InternalServerError": "The server encountered an unexpected error when processing the request.",
     }
 
     def map(self, id: str) -> str:
@@ -51,27 +58,3 @@ class Options:
             return caption
 
         raise KeyError(f"no caption found for ID: {id}")
-
-
-@dataclass
-class ErrorMessage:
-    """
-    Encapsulates an error message from an endpoint.
-
-    :param id: A machine-processable identifier for the error.
-    :param message: A human-readable description for the error.
-    """
-
-    id: str
-    message: str
-
-
-@dataclass
-class ErrorResponse:
-    """
-    Encapsulates an error response from an endpoint.
-
-    :param error: Details related to the error.
-    """
-
-    error: ErrorMessage
